#
# spec file for package reveng
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2017-2022, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           reveng
Version:        3.0.5
Release:        2.3
Summary:        An arbitrary-precision CRC calculator and algorithm finder
License:        GPL-3.0-or-later
Group:          Development/Tools/Other
URL:            https://reveng.sourceforge.io
Source:         http://sourceforge.net/projects/%{name}/files/%{version}/%{name}-%{version}.tar.xz
Patch0:         reveng-dont-strip.patch
Patch1:         reveng-obey-cflags.patch
Patch2:         reveng-presets_x86_64.patch
Patch3:         reveng-presets_i386.patch

%description
CRC RevEng is an arbitrary-precision CRC calculator and
algorithm finder. It calculates CRCs using any of the 72 preset
algorithms, or a user-specified algorithm to any width. It calculates
reversed CRCs to give the bit pattern that produces a desired forward
CRC. CRC RevEng also reverse-engineers any CRC algorithm from
sufficient correctly formatted message-CRC pairs and optional known
parameters. It comprises input interpretation options.
It is compliant with Ross Williams' Rocksoft model of parametrised CRC
algorithms.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1
%ifarch x86_64
%patch -P 2 -p1
%endif
%ifarch %{ix86}
%patch -P 3 -p1
%endif

%build
%ifarch %{ix86} x86_64
export CFLAGS="%{optflags}"
make %{?_smp_mflags}
%else
cc %{optflags} -Wall -ansi -c bmpbit.c cli.c model.c poly.c preset.c reveng.c
cc %{optflags} -o reveng bmpbit.o cli.o model.o poly.o preset.o reveng.o
%endif

%install
install -Dpm 0755 reveng %{buildroot}/%{_bindir}/reveng

%files
%license COPYING
%doc CHANGES README
%{_bindir}/reveng

%changelog
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Aug 31 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.5
  * Added alias CRC-16/BLUETOOTH from the CRC Catalogue.
- Update to version 3.0.4
  * Added algorithm CRC-64/REDIS from the CRC Catalogue.
* Sun May  8 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.3
  * Added algorithm CRC-16/M17 from the CRC Catalogue.
- Update to version 3.0.2
  * Reading a file which exceeds the size limit of polynomials
    causes an error.
* Tue Jan 11 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.1
  * Added algorithms CRC-32/MEF and CRC-64/MS from the CRC
    catalogue.
* Sat Jan  1 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.0
  * Reduces or eliminates brute force search for POLY in many
    cases by finding the greatest common divisor of differences
    between codewords.
* Tue Dec 28 2021 Martin Hauke <mardnh@gmx.de>
- Upstream changed the tarball
* Mon Dec 27 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.2
  * Added algorithm CRC-8/HITAG from the CRC Catalogue.
* Sun Aug 16 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.1
  * Updated project URL.
* Mon Dec  9 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.0
  * Added -1 switch to skip equivalent forms.
  * WIDTH may be specified before or after -i, -p, -q or -x.
  * Warnings are given if POLY has no +1 term or if a search
    is attempted with fewer than 4 codeword samples.
* Mon Nov 18 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.3
  * Added tomtorfs-wrapper.
  * Revised poly class definitions and function entry conditions
    in poly.c.
  * Added DFSFIX veneer for ARM Tube OS binary.
* Mon Nov  4 2019 Martin Hauke <mardnh@gmx.de>
- Revert to http download since obs seems to have some issues
  with https downloads from sourceforge
* Sun Nov  3 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.2
  * The memory allocation expands geometrically while reading
    polynomials from files; this improves performance on large
    files but memory overhead is increased during the read.
  * The argument index is initialized at run time, allowing
    RISC OS and ARM Tube OS users to re-invoke CRC RevEng from
    memory using *Go.
  * Replaced getopt library.
  * Removed underscores from system calls.
  * Updated documentation.
* Sat May 11 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.1
  * Improved robustness of reveng()
* Mon May  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.0
  * Much faster brute force search for generator polynomials if
    the most compact difference between right-aligned arguments is
    not more than twice the specified WIDTH.
* Sat Apr 20 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.6.3
  * Added algorithm CRC-32/CD-ROM-EDC from the CRC Catalogue.
  * Model class of CRC-16/ARC, CRC-16/GSM changed to 'attested'.
  * Error message advises that a positive -P may also precede -s.
* Wed Mar  6 2019 Martin Hauke <mardnh@gmx.de>
- Use HTTP instead of HTTPS in the Source URL.
* Tue Mar  5 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.6.2
  * Added algorithm CRC-8/MIFARE-MAD from the CRC Catalogue.
* Mon Feb 18 2019 Martin Hauke <mardnh@gmx.de>
- Build with preset models for x86_64 and ix86
- Add patches:
  * reveng-obey-cflags.patch
  * reveng-dont-strip.patch
  * reveng-x86_64.patch
  * reveng-presets_i386.patch
* Fri Feb 15 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure description is neutral and adheres to trademark
  guidelines.
* Fri Jan 11 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.6.1
  * mnovel() clears the model's class flags.
  version 1.6.0
  * Added 2 new algorithms, CRC-8/NRSC-5, CRC-16/NRSC-5, from the
    CRC Catalogue.
  * Renamed 31 algorithms; added 24 aliases to the old names.
  * Added 10 other aliases.
  * Added class descriptors to models[].
- Spec cleanup
* Fri Jul 27 2018 mardnh@gmx.de
- Update to version 1.5.3
  * Added algorithm CRC-24/OS-9 from the CRC Catalogue.
  * Optimised prev()
  * Optimised definition of struct malias.
  * Renamed NOFORCE to ALWPCK.
* Wed Jun 21 2017 mardnh@gmx.de
- Update to version 1.5.2
  * Added 3 new algorithms, CRC-8/BLUETOOTH, CRC-17/CAN-FD,
    CRC-21/CAN-FD, from the CRC Catalogue.
- Update to version 1.5.1
  * Added 8 new algorithms, CRC-3/GSM, CRC-6/GSM, CRC-8/GSM-A,
    CRC-8/GSM-B, CRC-10/GSM, CRC-12/GSM, CRC-14/GSM, CRC-16/GSM,
    from the CRC Catalogue.
  * -G is ignored if a generator polynomial is specified, so that
    it serves as a general fast-run switch.  The brute force
    search pass is then allowed to return results on the
    polynomial.
  * Revised calculation of residue for crossed-endian algorithms.
- Update to version 1.5.0
  * Added algorithm CRC-64/GO-ISO and 2 new aliases,
    CRC-64/ECMA-182, CRC-64/GO-ECMA, from the CRC Catalogue.
  * Added a residue field to Williams model output records.
  * Added -G switch to skip the brute force search pass.
* Sun Jul 31 2016 mardnh@gmx.de
- Update to version 1.4.4
  * Added 5 new algorithms, CRC-8/AUTOSAR, CRC-8/OPENSAFETY,
    CRC-16/OPENSAFETY-A, CRC-16/OPENSAFETY-B and CRC-32/AUTOSAR
    from the CRC Catalogue.
  * Added a build option to verify the order of the preset and
    alias tables at compile time.
- Update to version 1.4.3
  * Added algorithm CRC-16/CMS from the CRC Catalogue.
- Update to version 1.4.2
  * Added algorithm CRC-16/PROFIBUS from the CRC Catalogue.
- Update to version 1.4.1a
  * Fixed a regression that caused the Windows release to crash
    on older systems.
- Update to version 1.4.1
  * -P sets the Width value just like -k.
  * pcmp() quickly returns when the comparands are identical.
  * Added resources for the Windows executable.
- Update to version 1.4.0
  * Added 11 new algorithms, CRC-4/INTERLAKEN, CRC-7/UMTS,
    CRC-8/LTE, CRC-8/SAE-J1850, CRC-11/UMTS, CRC-16/LJ1200,
    CRC-24/BLE, CRC-24/INTERLAKEN, CRC-24/LTE-A, CRC-24/LTE-B,
    CRC-30/CDMA, and 4 new aliases, CRC-12/UMTS, CRC-16/LTE,
    CRC-16/UMTS, CRC-32/INTERLAKEN, from the CRC Catalogue.
  * Eliminated string comparison when testing if a model name is
    an alias.
  * Split off presets into preset.c.
  * Eliminated bogus calls to bsearch() in preset.c.
* Wed Feb 10 2016 mardnh@gmx.de
- initial package
